@@ -29,6 +29,7 @@ class ConfigTests(unittest.TestCase):
                           'password',
                           '10',
                           True,
+                          5.0,
                           None),
                          c.check_config('examples/bu2sw.conf'))
 
@@ -39,5 +40,17 @@ class ConfigTests(unittest.TestCase):
                           'password',
                           '10',
                           False,
+                          5.0,
                           None),
                          c.check_config('examples/bu2sw_ignore_verify.conf'))
+
+    def test_check_config_timeout(self):
+        """ unit test for check_config ignore case """
+        self.assertEqual(('https://example.org/auth/v1.0',
+                          'username',
+                          'password',
+                          '10',
+                          True,
+                          10.0,
+                          None),
+                         c.check_config('examples/bu2sw_timeout.conf'))
